@@ -1,5 +1,5 @@
 # MixtComp version 4 - july 2019
-# Copyright (C) Inria - Université de Lille - CNRS 
+# Copyright (C) Inria - Université de Lille - CNRS
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -9,7 +9,7 @@
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU Affero General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>
 
@@ -17,31 +17,40 @@
 # @author Quentin Grimonprez
 context("run functions")
 
-# These tests are skipped on cran to keep elapsed time < 10min
+# These tests are skipped on CRAN to keep elapsed time < 10min
 
 Sys.setenv(MC_DETERMINISTIC = 2)
 
 test_that("mixtCompLearn works in basic mode + predict", {
   skip_on_cran()
   set.seed(42, kind = "Mersenne-Twister", normal.kind = "Inversion")
-  
+
   ## data.frame object
-  dat <- data.frame(cont = c(rnorm(150, -2, 0.8), rnorm(150, 2, 0.8)),
-                    categ = c("a", "b")[c(apply(rmultinom(150, 1, c(0.5, 0.5)), 2, which.max), apply(rmultinom(150, 1, c(0.2, 0.8)), 2, which.max))],
-                    poiss = c(rpois(150, 2), rpois(150, 5)))
-  dat$categ[c(1, 10)] = NA
-  dat$cont[c(2, 5)] = NA
-  
+  dat <- data.frame(
+    cont = c(rnorm(150, -2, 0.8), rnorm(150, 2, 0.8)),
+    categ = c("a", "b")[c(
+      apply(rmultinom(150, 1, c(0.5, 0.5)), 2, which.max),
+      apply(rmultinom(150, 1, c(0.2, 0.8)), 2, which.max)
+    )],
+    poiss = c(rpois(150, 2), rpois(150, 5))
+  )
+  dat$categ[c(1, 10)] <- NA
+  dat$cont[c(2, 5)] <- NA
+
   expect_warning(resLearn <- mixtCompLearn(dat, nClass = 2, nRun = 3, nCore = 1), regexp = NA)
-  
-  if(!is.null(resLearn$warnLog))
+
+  if (!is.null(resLearn$warnLog)) {
     print(resLearn$warnLog)
-  
+  }
+
   expect_equal(resLearn$warnLog, NULL)
   expect_gte(RMixtCompIO:::rand.index(getPartition(resLearn), rep(1:2, each = 150)), 0.9)
-  expect_lte(norm(getTik(resLearn, log = FALSE) - getEmpiricTik(resLearn))/resLearn$algo$nInd, 0.1)
-  
-  expect_equal(resLearn$variable$type, list(z_class = "LatentClass", cont = "Gaussian", categ = "Multinomial", poiss = "Poisson"))
+  expect_lte(norm(getTik(resLearn, log = FALSE) - getEmpiricTik(resLearn)) / resLearn$algo$nInd, 0.1)
+
+  expect_equal(
+    resLearn$variable$type,
+    list(z_class = "LatentClass", cont = "Gaussian", categ = "Multinomial", poiss = "Poisson")
+  )
   expect_true(resLearn$algo$basicMode)
   expect_false(resLearn$algo$hierarchicalMode)
   expect_equal(resLearn$algo$dictionary, list(categ = list(old = c("a", "b"), new = c("1", "2"))))
@@ -49,46 +58,66 @@ test_that("mixtCompLearn works in basic mode + predict", {
   expect_equal(names(resLearn$variable$data$categ$stat), c("1", "10"))
   expect_equal(sort(resLearn$variable$data$categ$stat[["1"]][, 1]), c("a", "b"))
   expect_equal(sort(resLearn$variable$data$categ$stat[["10"]][, 1]), c("a", "b"))
-  expect_equal(rownames(resLearn$variable$param$categ$stat), c("k: 1, modality: a", "k: 1, modality: b", "k: 2, modality: a", "k: 2, modality: b"))
-  
-  
-  
-  expect_warning(resPredict <- mixtCompPredict(dat, resLearn = resLearn), regexp = NA)
-  
-  if(!is.null(resPredict$warnLog))
+  expect_equal(
+    rownames(resLearn$variable$param$categ$stat),
+    c("k: 1, modality: a", "k: 1, modality: b", "k: 2, modality: a", "k: 2, modality: b")
+  )
+
+
+  expect_warning(resPredict <- mixtCompPredict(dat, resLearn = resLearn, nCore = 1), regexp = NA)
+
+  if (!is.null(resPredict$warnLog)) {
     print(resPredict$warnLog)
-  
+  }
+
   expect_equal(resPredict$warnLog, NULL)
   expect_gte(RMixtCompIO:::rand.index(getPartition(resPredict), rep(1:2, each = 150)), 0.9)
   expect_equal(resPredict$algo[1:7], resLearn$algo[1:7]) # check that algo param form resLearn are used
   expect_true(resPredict$algo$basicMode)
   expect_equal(resPredict$algo$dictionary, list(categ = list(old = c("a", "b"), new = c("1", "2"))))
   expect_equal(resPredict$variable$data$categ$completed[!is.na(dat$categ)], as.character(dat$categ)[!is.na(dat$categ)])
-  expect_equal(rownames(resPredict$variable$param$categ$stat), c("k: 1, modality: a", "k: 1, modality: b", "k: 2, modality: a", "k: 2, modality: b"))
-  
-  
+  expect_equal(
+    rownames(resPredict$variable$param$categ$stat),
+    c("k: 1, modality: a", "k: 1, modality: b", "k: 2, modality: a", "k: 2, modality: b")
+  )
+
+
   ## list object
-  dat <- list(cont = c(rnorm(150, -2, 0.8), rnorm(150, 2, 0.8)),
-              categ1 = as.character(c(apply(rmultinom(150, 1, c(0.5, 0.5)), 2, which.max), apply(rmultinom(150, 1, c(0.2, 0.8)), 2, which.max))),
-              categ2 = as.factor(c(apply(rmultinom(150, 1, c(0.5, 0.5)), 2, which.max), apply(rmultinom(150, 1, c(0.2, 0.8)), 2, which.max))),
-              poiss = c(rpois(150, 2), rpois(150, 5)))
-  dat$categ1[c(1, 10)] = NA
-  dat$categ2[c(2, 11)] = NA
- 
-  expect_warning(resLearn <- mixtCompLearn(dat, nClass = 2), regexp = NA)
-  
-  if(!is.null(resLearn$warnLog))
+  dat <- list(
+    cont = c(rnorm(150, -2, 0.8), rnorm(150, 2, 0.8)),
+    categ1 = as.character(c(
+      apply(rmultinom(150, 1, c(0.5, 0.5)), 2, which.max),
+      apply(rmultinom(150, 1, c(0.2, 0.8)), 2, which.max)
+    )),
+    categ2 = as.factor(c(
+      apply(rmultinom(150, 1, c(0.5, 0.5)), 2, which.max),
+      apply(rmultinom(150, 1, c(0.2, 0.8)), 2, which.max)
+    )),
+    poiss = c(rpois(150, 2), rpois(150, 5))
+  )
+  dat$categ1[c(1, 10)] <- NA
+  dat$categ2[c(2, 11)] <- NA
+
+  expect_warning(resLearn <- mixtCompLearn(dat, nClass = 2, nCore = 1), regexp = NA)
+
+  if (!is.null(resLearn$warnLog)) {
     print(resLearn$warnLog)
-  
+  }
+
   expect_equal(resLearn$warnLog, NULL)
   expect_gte(RMixtCompIO:::rand.index(getPartition(resLearn), rep(1:2, each = 150)), 0.9)
-  expect_lte(norm(getTik(resLearn, log = FALSE) - getEmpiricTik(resLearn))/resLearn$algo$nInd, 0.1)
-  
-  expect_equal(resLearn$variable$type, list(z_class = "LatentClass", cont = "Gaussian", categ1 = "Multinomial", categ2 = "Multinomial", poiss = "Poisson"))
+  expect_lte(norm(getTik(resLearn, log = FALSE) - getEmpiricTik(resLearn)) / resLearn$algo$nInd, 0.1)
+
+  expect_equal(
+    resLearn$variable$type,
+    list(z_class = "LatentClass", cont = "Gaussian", categ1 = "Multinomial", categ2 = "Multinomial", poiss = "Poisson")
+  )
   expect_true(resLearn$algo$basicMode)
   expect_false(resLearn$algo$hierarchicalMode)
-  expect_equal(resLearn$algo$dictionary, list(categ1 = list(old = c("1", "2"), new = c("1", "2")),
-                                              categ2 = list(old = c("1", "2"), new = c("1", "2"))))
+  expect_equal(resLearn$algo$dictionary, list(
+    categ1 = list(old = c("1", "2"), new = c("1", "2")),
+    categ2 = list(old = c("1", "2"), new = c("1", "2"))
+  ))
   expect_equal(resLearn$variable$data$categ1$completed[!is.na(dat$categ1)], as.character(dat$categ1)[!is.na(dat$categ1)])
   expect_equal(resLearn$variable$data$categ2$completed[!is.na(dat$categ2)], as.character(dat$categ2)[!is.na(dat$categ2)])
   expect_equal(names(resLearn$variable$data$categ1$stat), c("1", "10"))
@@ -97,91 +126,122 @@ test_that("mixtCompLearn works in basic mode + predict", {
   expect_equal(names(resLearn$variable$data$categ2$stat), c("2", "11"))
   expect_equal(sort(resLearn$variable$data$categ2$stat[["2"]][, 1]), c("1", "2"))
   expect_equal(sort(resLearn$variable$data$categ2$stat[["11"]][, 1]), c("1", "2"))
-  expect_equal(rownames(resLearn$variable$param$categ1$stat), c("k: 1, modality: 1", "k: 1, modality: 2", "k: 2, modality: 1", "k: 2, modality: 2"))
-  expect_equal(rownames(resLearn$variable$param$categ2$stat), c("k: 1, modality: 1", "k: 1, modality: 2", "k: 2, modality: 1", "k: 2, modality: 2"))
+  expect_equal(
+    rownames(resLearn$variable$param$categ1$stat),
+    c("k: 1, modality: 1", "k: 1, modality: 2", "k: 2, modality: 1", "k: 2, modality: 2")
+  )
+  expect_equal(
+    rownames(resLearn$variable$param$categ2$stat),
+    c("k: 1, modality: 1", "k: 1, modality: 2", "k: 2, modality: 1", "k: 2, modality: 2")
+  )
   expect_type(getCompletedData(resLearn)$cont, "double")
-  
-  
-  
-  expect_warning(resPredict <- mixtCompPredict(dat, resLearn = resLearn), regexp = NA)
-  
-  if(!is.null(resPredict$warnLog))
+
+
+
+  expect_warning(resPredict <- mixtCompPredict(dat, resLearn = resLearn, nCore = 1), regexp = NA)
+
+  if (!is.null(resPredict$warnLog)) {
     print(resPredict$warnLog)
-  
+  }
+
   expect_equal(resPredict$warnLog, NULL)
   expect_gte(RMixtCompIO:::rand.index(getPartition(resPredict), rep(1:2, each = 150)), 0.9)
-  expect_lte(norm(getTik(resPredict, log = FALSE) - getEmpiricTik(resPredict))/resPredict$algo$nInd, 0.1)
+  expect_lte(norm(getTik(resPredict, log = FALSE) - getEmpiricTik(resPredict)) / resPredict$algo$nInd, 0.1)
   expect_true(resPredict$algo$basicMode)
-  expect_equal(resPredict$algo$dictionary, list(categ1 = list(old = c("1", "2"), new = c("1", "2")),
-                                                categ2 = list(old = c("1", "2"), new = c("1", "2"))))
+  expect_equal(resPredict$algo$dictionary, list(
+    categ1 = list(old = c("1", "2"), new = c("1", "2")),
+    categ2 = list(old = c("1", "2"), new = c("1", "2"))
+  ))
   expect_equal(resPredict$variable$data$categ1$completed[!is.na(dat$categ1)], as.character(dat$categ1)[!is.na(dat$categ1)])
   expect_equal(resPredict$variable$data$categ2$completed[!is.na(dat$categ2)], as.character(dat$categ2)[!is.na(dat$categ2)])
-  expect_equal(rownames(resPredict$variable$param$categ1$stat), c("k: 1, modality: 1", "k: 1, modality: 2", "k: 2, modality: 1", "k: 2, modality: 2"))
-  expect_equal(rownames(resPredict$variable$param$categ2$stat), c("k: 1, modality: 1", "k: 1, modality: 2", "k: 2, modality: 1", "k: 2, modality: 2"))
-  
-  
-  
+  expect_equal(
+    rownames(resPredict$variable$param$categ1$stat),
+    c("k: 1, modality: 1", "k: 1, modality: 2", "k: 2, modality: 1", "k: 2, modality: 2")
+  )
+  expect_equal(
+    rownames(resPredict$variable$param$categ2$stat),
+    c("k: 1, modality: 1", "k: 1, modality: 2", "k: 2, modality: 1", "k: 2, modality: 2")
+  )
+
+
+
   ## with z_class and without multinomial
-  dat$z_class = rep(1:2, each = 150)
-  dat$categ1 = NULL
-  dat$categ2 = NULL
-  
-  expect_warning(resLearn <- mixtCompLearn(dat, nClass = 2), regexp = NA)
-  
-  if(!is.null(resLearn$warnLog))
+  dat$z_class <- rep(1:2, each = 150)
+  dat$categ1 <- NULL
+  dat$categ2 <- NULL
+
+  expect_warning(resLearn <- mixtCompLearn(dat, nClass = 2, nCore = 1), regexp = NA)
+
+  if (!is.null(resLearn$warnLog)) {
     print(resLearn$warnLog)
-  
+  }
+
   expect_equal(resLearn$warnLog, NULL)
   expect_gte(RMixtCompIO:::rand.index(getPartition(resLearn), rep(1:2, each = 150)), 0.95)
   expect_equal(resLearn$variable$type, list(z_class = "LatentClass", cont = "Gaussian", poiss = "Poisson"))
   expect_true(resLearn$algo$basicMode)
   expect_false(resLearn$algo$hierarchicalMode)
   expect_equal(resLearn$algo$dictionary, list())
-  
-  
-  dat$z_class = NULL
-  expect_warning(resPredict <- mixtCompPredict(dat, resLearn = resLearn), regexp = NA)
+
+
+  dat$z_class <- NULL
+  expect_warning(resPredict <- mixtCompPredict(dat, resLearn = resLearn, nCore = 1), regexp = NA)
   expect_gte(RMixtCompIO:::rand.index(getPartition(resPredict), rep(1:2, each = 150)), 0.95)
   expect_true(resPredict$algo$basicMode)
   expect_equal(resPredict$algo$dictionary, list())
 })
 
 
-
 test_that("plot in basic mode + predict works with z_class as character", {
   skip_on_cran()
   data(iris)
-  
-  names(iris)[5] = "z_class"
-  
-  expect_warning(resLearn <- mixtCompLearn(iris, nClass = 3), regexp = NA)
-  
-  if(!is.null(resLearn$warnLog))
+
+  names(iris)[5] <- "z_class"
+
+  expect_warning(resLearn <- mixtCompLearn(iris, nClass = 3, nCore = 1), regexp = NA)
+
+  if (!is.null(resLearn$warnLog)) {
     print(resLearn$warnLog)
-  
+  }
+
   expect_equal(resLearn$warnLog, NULL)
-  expect_lte(norm(getTik(resLearn, log = FALSE) - getEmpiricTik(resLearn))/resLearn$algo$nInd, 0.1)
-  
-  expect_equal(resLearn$variable$type, list(z_class = "LatentClass", Sepal.Length = "Gaussian", Sepal.Width = "Gaussian", Petal.Length = "Gaussian", Petal.Width = "Gaussian"))
+  expect_lte(norm(getTik(resLearn, log = FALSE) - getEmpiricTik(resLearn)) / resLearn$algo$nInd, 0.1)
+
+  expect_equal(
+    resLearn$variable$type,
+    list(
+      z_class = "LatentClass", Sepal.Length = "Gaussian", Sepal.Width = "Gaussian",
+      Petal.Length = "Gaussian", Petal.Width = "Gaussian"
+    )
+  )
   expect_true(resLearn$algo$basicMode)
   expect_false(resLearn$algo$hierarchicalMode)
-  expect_equal(resLearn$algo$dictionary, list(z_class = list(old = c("setosa", "versicolor", "virginica"), new = c("1", "2", "3"))))
+  expect_equal(
+    resLearn$algo$dictionary,
+    list(z_class = list(old = c("setosa", "versicolor", "virginica"), new = c("1", "2", "3")))
+  )
   expect_equal(resLearn$variable$data$z_class$completed, as.character(iris$z_class))
   expect_equal(rownames(resLearn$variable$param$z_class$stat), c("k: setosa", "k: versicolor", "k: virginica"))
-  
-  expect_warning(resPredict <- mixtCompPredict(iris[, 1:4], resLearn = resLearn), regexp = NA)
-  
-  if(!is.null(resPredict$warnLog))
+
+  expect_warning(resPredict <- mixtCompPredict(iris[, 1:4], resLearn = resLearn, nCore = 1), regexp = NA)
+
+  if (!is.null(resPredict$warnLog)) {
     print(resPredict$warnLog)
-  
+  }
+
   expect_equal(resPredict$warnLog, NULL)
-  expect_equal(resPredict$algo$dictionary, list(z_class = list(old = c("setosa", "versicolor", "virginica"), new = c("1", "2", "3"))))
+  expect_equal(
+    resPredict$algo$dictionary,
+    list(z_class = list(old = c("setosa", "versicolor", "virginica"), new = c("1", "2", "3")))
+  )
   expect_equal(rownames(resPredict$variable$param$z_class$stat), c("k: setosa", "k: versicolor", "k: virginica"))
-  
-  
-  w <- capture_warnings(plotDiscrimClass(resLearn, pkg = "plotly"))# the first call generates warnings due to packages loading
-  if(length(w) > 0)
+
+
+  w <- capture_warnings(plotDiscrimClass(resLearn, pkg = "plotly")) # the first call generates warnings due to packages loading
+  if (length(w) > 0) {
     expect_match(w, "replacing previous", all = TRUE)
+  }
+
   expect_warning(plotDiscrimClass(resLearn, pkg = "ggplot2"), regexp = NA)
   expect_warning(heatmapClass(resLearn, pkg = "ggplot2"), regexp = NA)
   expect_warning(heatmapTikSorted(resLearn, pkg = "ggplot2"), regexp = NA)
@@ -189,44 +249,38 @@ test_that("plot in basic mode + predict works with z_class as character", {
   expect_warning(heatmapTikSorted(resLearn, pkg = "plotly"), regexp = NA)
   expect_warning(histMisclassif(resLearn, pkg = "ggplot2"), regexp = NA)
   expect_warning(histMisclassif(resLearn, pkg = "plotly"), regexp = NA)
-  
-  for(name in getVarNames(resLearn))
-  {
+
+  for (name in getVarNames(resLearn)) {
     expect_warning(plotParamConvergence(resLearn, name), regexp = NA)
     expect_warning(plotDataCI(resLearn, name, pkg = "plotly"), regexp = NA)
     expect_warning(plotDataCI(resLearn, name, pkg = "ggplot2"), regexp = NA)
     expect_warning(plotDataBoxplot(resLearn, name, pkg = "plotly"), regexp = NA)
     expect_warning(plotDataBoxplot(resLearn, name, pkg = "ggplot2"), regexp = NA)
   }
-  
+
   expect_warning(plotProportion(resLearn, pkg = "ggplot2"), regexp = NA)
   expect_warning(plotProportion(resLearn, pkg = "plotly"), regexp = NA)
   expect_warning(plot(resLearn, pkg = "ggplot2"), regexp = NA)
   expect_warning(plot(resLearn, pkg = "plotly"), regexp = NA)
   unlink("Rplots.pdf")
-  
-  
 })
 
 
-
-
-
 test_that("mixtCompLearn works + mixtCompPredict + predict", {
   skip_on_cran()
   set.seed(42, kind = "Mersenne-Twister", normal.kind = "Inversion")
-  
+
   nInd <- 2000
-  
+
   var <- list()
   var$z_class <- RMixtCompIO:::zParam()
   var$z_class$param <- c(0.2, 0.3, 0.15, 0.35)
   var$Gaussian1 <- RMixtCompIO:::gaussianParam("Gaussian1")
   var$Gaussian1$param[[3]] <- list(mean = -1.5, sd = 0.4)
   var$Gaussian1$param[[4]] <- list(mean = 1.5, sd = 0.4)
-  
+
   resGen <- RMixtCompIO:::dataGeneratorNewIO(nInd, 0.95, var)
-  
+
   algo <- list(
     nbBurnInIter = 100,
     nbIter = 100,
@@ -237,22 +291,23 @@ test_that("mixtCompLearn works + mixtCompPredict + predict", {
     nInitPerClass = 100,
     confidenceLevel = 0.95
   )
-  
+
   data <- do.call(cbind, resGen$data)
   desc <- list(z_class = "LatentClass", Gaussian1 = "Gaussian")
-  
-  resLearn <- mixtCompLearn(data, desc, algo, nClass = 4, crit = "ICL", verbose = FALSE, nRun = 3, nCore = 1) 
-  
-  if(!is.null(resLearn$warnLog))
+
+  resLearn <- mixtCompLearn(data, desc, algo, nClass = 4, crit = "ICL", verbose = FALSE, nRun = 3, nCore = 1)
+
+  if (!is.null(resLearn$warnLog)) {
     print(resLearn$warnLog)
-  
+  }
+
   expect_equal(resLearn$warnLog, NULL)
   expect_gte(RMixtCompIO:::rand.index(getPartition(resLearn), resGen$z), 0.9)
-  expect_lte(norm(getTik(resLearn, log = FALSE) - getEmpiricTik(resLearn))/resLearn$algo$nInd, 0.1)
-  
+  expect_lte(norm(getTik(resLearn, log = FALSE) - getEmpiricTik(resLearn)) / resLearn$algo$nInd, 0.1)
+
   confMatSampled <- table(resGen$z, getPartition(resLearn))
   print(confMatSampled)
-  
+
   expect_equal(names(resLearn), c("mixture", "variable", "algo", "nRun", "criterion", "crit", "nClass", "res", "totalTime"))
   expect_equal(resLearn$criterion, "ICL")
   expect_equal(resLearn$nRun, 3)
@@ -284,39 +339,40 @@ test_that("mixtCompLearn works + mixtCompPredict + predict", {
   expect_equal(dim(disc), rep(4, 2))
   expect_warning(disc <- computeSimilarityVar(resLearn), regexp = NA)
   expect_equal(dim(disc), rep(1, 2))
-  for(name in getVarNames(resLearn))
+  for (name in getVarNames(resLearn)) {
     expect_warning(getParam(resLearn, name), regexp = NA)
-  
-  
-  expect_warning(resPredict <- mixtCompPredict(data, desc, resLearn = resLearn, verbose = FALSE), regexp = NA)
-  expect_lte(norm(getTik(resPredict, log = FALSE) - getEmpiricTik(resPredict))/resPredict$algo$nInd, 0.1)
+  }
+
+
+  expect_warning(resPredict <- mixtCompPredict(data, desc, resLearn = resLearn, verbose = FALSE, nCore = 1), regexp = NA)
+  expect_lte(norm(getTik(resPredict, log = FALSE) - getEmpiricTik(resPredict)) / resPredict$algo$nInd, 0.1)
   expect_equal(names(resPredict), c("mixture", "variable", "algo"))
   expect_equal(resPredict$algo$mode, "predict")
   expect_equal(resPredict$algo[1:7], resLearn$algo[1:7]) # check that algo param form resLearn are used
-  
-  
+
+
   expect_warning(outPred <- predict(resLearn, type = "partition"), regexp = NA)
   expect_equal(outPred, getPartition(resLearn, empiric = FALSE))
   expect_warning(outPred <- predict(resLearn, data, type = "probabilities", nClass = 4), regexp = NA)
   expect_equal(dim(outPred), c(nInd, 4))
-  
 })
 
+
 test_that("mixtCompLearn works with a vector for nClass + mixtCompPredict + verbose", {
   skip_on_cran()
   set.seed(42, kind = "Mersenne-Twister", normal.kind = "Inversion")
-  
+
   nInd <- 1000
-  
+
   var <- list()
   var$z_class <- RMixtCompIO:::zParam()
   var$z_class$param <- c(0.2, 0.3, 0.15, 0.35)
   var$Gaussian1 <- RMixtCompIO:::gaussianParam("Gaussian1")
   var$Gaussian1$param[[3]] <- list(mean = -2, sd = 0.5)
   var$Gaussian1$param[[4]] <- list(mean = 2, sd = 0.5)
-  
+
   resGen <- RMixtCompIO:::dataGeneratorNewIO(nInd, 0.9, var)
-  
+
   algo <- list(
     nbBurnInIter = 100,
     nbIter = 100,
@@ -326,22 +382,23 @@ test_that("mixtCompLearn works with a vector for nClass + mixtCompPredict + verb
     nInitPerClass = 100,
     confidenceLevel = 0.95
   )
-  
+
   data <- do.call(cbind, resGen$data)
   desc <- list(z_class = list(type = "LatentClass"), Gaussian1 = list(type = "Gaussian", paramStr = ""))
-  
-  resLearn <- mixtCompLearn(data, desc, algo, nClass = 2:5, nRun = 5, nCore = 1, verbose = TRUE) 
-  
-  if(!is.null(resLearn$warnLog))
+
+  resLearn <- mixtCompLearn(data, desc, algo, nClass = 2:5, nRun = 5, nCore = 1, verbose = TRUE)
+
+  if (!is.null(resLearn$warnLog)) {
     print(resLearn$warnLog)
-  
+  }
+
   expect_equal(resLearn$warnLog, NULL)
   expect_gte(RMixtCompIO:::rand.index(getPartition(resLearn), resGen$z), 0.85)
-  expect_lte(norm(getTik(resLearn, log = FALSE) - getEmpiricTik(resLearn))/resLearn$algo$nInd, 0.1)
-  
+  expect_lte(norm(getTik(resLearn, log = FALSE) - getEmpiricTik(resLearn)) / resLearn$algo$nInd, 0.1)
+
   confMatSampled <- table(resGen$z, getPartition(resLearn))
   print(confMatSampled)
-  
+
   expect_equal(names(resLearn), c("mixture", "variable", "algo", "nRun", "criterion", "crit", "nClass", "res", "totalTime"))
   expect_equal(resLearn$nRun, 5)
   expect_equal(resLearn$criterion, "BIC")
@@ -373,14 +430,16 @@ test_that("mixtCompLearn works with a vector for nClass + mixtCompPredict + verb
   expect_equal(dim(disc), rep(4, 2))
   expect_warning(disc <- computeSimilarityVar(resLearn), regexp = NA)
   expect_equal(dim(disc), rep(1, 2))
-  for(name in getVarNames(resLearn))
+  for (name in getVarNames(resLearn)) {
     expect_warning(getParam(resLearn, name), regexp = NA)
-  
+  }
+
   # test plot functions
   expect_warning(plotConvergence(resLearn), regexp = NA)
-  w <- capture_warnings(plotDiscrimClass(resLearn, pkg = "plotly"))# the first call generates warnings due to packages loading
-  if(length(w) > 0)
+  w <- capture_warnings(plotDiscrimClass(resLearn, pkg = "plotly")) # the first call generates warnings due to packages loading
+  if (length(w) > 0) {
     expect_match(w, "replacing previous", all = TRUE)
+  }
   expect_warning(plotDiscrimVar(resLearn, pkg = "plotly"), regexp = NA)
   expect_warning(plotDiscrimClass(resLearn, pkg = "ggplot2"), regexp = NA)
   expect_warning(plotDiscrimVar(resLearn, pkg = "ggplot2"), regexp = NA)
@@ -392,15 +451,13 @@ test_that("mixtCompLearn works with a vector for nClass + mixtCompPredict + verb
   expect_warning(heatmapTikSorted(resLearn, pkg = "plotly"), regexp = NA)
   expect_warning(histMisclassif(resLearn, pkg = "plotly"), regexp = NA)
   expect_warning(histMisclassif(resLearn, pkg = "ggplot2"), regexp = NA)
-  for(name in getVarNames(resLearn))
-  {
-    if(resLearn$variable$type[[name]] != "Rank_ISR")
-    {
+  for (name in getVarNames(resLearn)) {
+    if (resLearn$variable$type[[name]] != "Rank_ISR") {
       expect_warning(plotDataCI(resLearn, name, pkg = "plotly"), regexp = NA)
       expect_warning(plotDataCI(resLearn, name, pkg = "ggplot2"), regexp = NA)
       expect_warning(plotDataBoxplot(resLearn, name, pkg = "plotly"), regexp = NA)
       expect_warning(plotDataBoxplot(resLearn, name, pkg = "ggplot2"), regexp = NA)
-    }else{
+    } else {
       expect_warning(plotDataCI(resLearn, name, pkg = "ggplot2"))
       expect_warning(plotDataCI(resLearn, name, pkg = "plotly"))
       expect_warning(plotDataBoxplot(resLearn, name, pkg = "ggplot2"))
@@ -416,19 +473,20 @@ test_that("mixtCompLearn works with a vector for nClass + mixtCompPredict + verb
   expect_warning(plot(resLearn, pkg = "ggplot2"), regexp = NA)
   expect_warning(plot(resLearn, pkg = "plotly"), regexp = NA)
   unlink("Rplots.pdf")
-  
+
   expect_warning(summary(resLearn), regexp = NA)
   expect_warning(summary(resLearn$res[[1]]), regexp = NA)
   expect_warning(print(resLearn), regexp = NA)
   expect_warning(print(resLearn$res[[1]]), regexp = NA)
-  
-  expect_warning(resPredict <- mixtCompPredict(data, desc, algo, resLearn, nClass = 3, verbose = TRUE), regexp = NA)
-  
-  if(!is.null(resPredict$warnLog))
+
+  expect_warning(resPredict <- mixtCompPredict(data, desc, algo, resLearn, nClass = 3, verbose = TRUE, nCore = 1), regexp = NA)
+
+  if (!is.null(resPredict$warnLog)) {
     print(resPredict$warnLog)
-  
-  expect_lte(norm(getTik(resPredict, log = FALSE) - getEmpiricTik(resPredict))/resPredict$algo$nInd, 0.1)
-  
+  }
+
+  expect_lte(norm(getTik(resPredict, log = FALSE) - getEmpiricTik(resPredict)) / resPredict$algo$nInd, 0.1)
+
   expect_equal(names(resPredict), c("mixture", "variable", "algo"))
   expect_equal(resPredict$algo$mode, "predict")
 })
@@ -437,10 +495,10 @@ test_that("mixtCompLearn works with a vector for nClass + mixtCompPredict + verb
 test_that("mixtCompLearn works in hierarchicalMode", {
   skip_on_cran()
   set.seed(42, kind = "Mersenne-Twister", normal.kind = "Inversion")
-  
+
   data(simData)
   model <- simData$model$unsupervised[c("Gaussian1", "Functional1")]
-  
+
   algo <- list(
     nbBurnInIter = 50,
     nbIter = 50,
@@ -450,17 +508,18 @@ test_that("mixtCompLearn works in hierarchicalMode", {
     nInitPerClass = 100,
     confidenceLevel = 0.95
   )
-  
-  
-  resLearn <- mixtCompLearn(simData$dataLearn$matrix, model, algo, nClass = 3, nRun = 2, nCore = 1, verbose = TRUE) 
-  
-  if(!is.null(resLearn$warnLog))
+
+
+  resLearn <- mixtCompLearn(simData$dataLearn$matrix, model, algo, nClass = 3, nRun = 2, nCore = 1, verbose = TRUE)
+
+  if (!is.null(resLearn$warnLog)) {
     print(resLearn$warnLog)
-  
+  }
+
   expect_equal(resLearn$warnLog, NULL)
   expect_gte(RMixtCompIO:::rand.index(getPartition(resLearn$res[[2]]), simData$dataLearn$data.frame$z_class), 0.85)
-  expect_lte(norm(getTik(resLearn$res[[2]], log = FALSE) - getEmpiricTik(resLearn$res[[2]]))/resLearn$algo$nInd, 0.1)
-  
+  expect_lte(norm(getTik(resLearn$res[[2]], log = FALSE) - getEmpiricTik(resLearn$res[[2]])) / resLearn$algo$nInd, 0.1)
+
   expect_equal(names(resLearn), c("mixture", "variable", "algo", "nRun", "criterion", "crit", "nClass", "res", "totalTime"))
   expect_equal(resLearn$nRun, 2)
   expect_equal(resLearn$criterion, "BIC")
@@ -488,14 +547,16 @@ test_that("mixtCompLearn works in hierarchicalMode", {
   expect_warning(disc <- computeSimilarityClass(resLearn), regexp = NA)
   expect_warning(disc <- computeSimilarityVar(resLearn), regexp = NA)
   expect_equal(dim(disc), rep(2, 2))
-  for(name in getVarNames(resLearn))
+  for (name in getVarNames(resLearn)) {
     expect_warning(getParam(resLearn, name), regexp = NA)
-  
+  }
+
   # test plot functions
   expect_warning(plotConvergence(resLearn), regexp = NA)
-  w <- capture_warnings(plotDiscrimClass(resLearn, pkg = "plotly"))# the first call generates warnings due to packages loading
-  if(length(w) > 0)
+  w <- capture_warnings(plotDiscrimClass(resLearn, pkg = "plotly")) # the first call generates warnings due to packages loading
+  if (length(w) > 0) {
     expect_match(w, "replacing previous", all = TRUE)
+  }
   expect_warning(plotDiscrimVar(resLearn, pkg = "plotly"), regexp = NA)
   expect_warning(plotDiscrimClass(resLearn, pkg = "ggplot2"), regexp = NA)
   expect_warning(plotDiscrimVar(resLearn, pkg = "ggplot2"), regexp = NA)
@@ -507,15 +568,13 @@ test_that("mixtCompLearn works in hierarchicalMode", {
   expect_warning(heatmapTikSorted(resLearn, pkg = "plotly"), regexp = NA)
   expect_warning(histMisclassif(resLearn, pkg = "plotly"), regexp = NA)
   expect_warning(histMisclassif(resLearn, pkg = "ggplot2"), regexp = NA)
-  for(name in getVarNames(resLearn))
-  {
-    if(resLearn$variable$type[[name]] != "Rank_ISR")
-    {
+  for (name in getVarNames(resLearn)) {
+    if (resLearn$variable$type[[name]] != "Rank_ISR") {
       expect_warning(plotDataCI(resLearn, name, pkg = "plotly"), regexp = NA)
       expect_warning(plotDataCI(resLearn, name, pkg = "ggplot2"), regexp = NA)
       expect_warning(plotDataBoxplot(resLearn, name, pkg = "plotly"), regexp = NA)
       expect_warning(plotDataBoxplot(resLearn, name, pkg = "ggplot2"), regexp = NA)
-    }else{
+    } else {
       expect_warning(plotDataCI(resLearn, name, pkg = "ggplot2"))
       expect_warning(plotDataCI(resLearn, name, pkg = "plotly"))
       expect_warning(plotDataBoxplot(resLearn, name, pkg = "ggplot2"))
@@ -531,18 +590,22 @@ test_that("mixtCompLearn works in hierarchicalMode", {
   expect_warning(plot(resLearn, pkg = "ggplot2"), regexp = NA)
   expect_warning(plot(resLearn, pkg = "plotly"), regexp = NA)
   unlink("Rplots.pdf")
-  
+
   expect_warning(summary(resLearn), regexp = NA)
   expect_warning(summary(resLearn$res[[1]]), regexp = NA)
   expect_warning(print(resLearn), regexp = NA)
   expect_warning(print(resLearn$res[[1]]), regexp = NA)
-  
-  
-  expect_warning(resPredict <- mixtCompPredict(simData$dataPredict$matrix, model, algo, resLearn, nClass = 2, verbose = TRUE), regexp = NA)
-  if(!is.null(resPredict$warnLog))
+
+
+  expect_warning(
+    resPredict <- mixtCompPredict(simData$dataPredict$matrix, model, algo, resLearn, nClass = 2, verbose = TRUE, nCore = 1),
+    regexp = NA
+  )
+  if (!is.null(resPredict$warnLog)) {
     print(resPredict$warnLog)
-  
-  expect_lte(norm(getTik(resPredict, log = FALSE) - getEmpiricTik(resPredict))/resPredict$algo$nInd, 0.1)
+  }
+
+  expect_lte(norm(getTik(resPredict, log = FALSE) - getEmpiricTik(resPredict)) / resPredict$algo$nInd, 0.1)
   expect_equal(names(resPredict), c("mixture", "variable", "algo"))
   expect_equal(resPredict$algo$mode, "predict")
 })
@@ -550,7 +613,7 @@ test_that("mixtCompLearn works in hierarchicalMode", {
 
 test_that("summary returns no warnings and no errors", {
   outMC <- list(warnLog = "Crash.")
-  
+
   expect_warning(summary(outMC), regexp = NA)
   expect_warning(print(outMC), regexp = NA)
 })
@@ -558,18 +621,19 @@ test_that("summary returns no warnings and no errors", {
 test_that("summary works + run without paramStr for functional", {
   skip_on_cran()
   data("simData")
-  simData$model$unsupervised$Functional1$paramStr = ""
-  
-  resLearn <- mixtCompLearn(simData$dataLearn$matrix, simData$model$unsupervised[-c(3:5, 7:8)], 
-                            algo = createAlgo(nbBurnInIter = 25, nbIter = 25, nbGibbsBurnInIter = 25, nbGibbsIter = 25), 
-                            nClass = 2, nRun = 1, nCore = 1, hierarchicalMode = "no") 
-  
+  simData$model$unsupervised$Functional1$paramStr <- ""
+
+  resLearn <- mixtCompLearn(simData$dataLearn$matrix, simData$model$unsupervised[-c(3:5, 7:8)],
+    algo = createAlgo(nbBurnInIter = 25, nbIter = 25, nbGibbsBurnInIter = 25, nbGibbsIter = 25),
+    nClass = 2, nRun = 1, nCore = 1, hierarchicalMode = "no"
+  )
+
   expect_equal(resLearn$variable$param$Functional1$paramStr, "nSub: 2, nCoeff: 2")
-  
+
   expect_warning(summary(resLearn), regexp = NA)
   expect_warning(summary(resLearn$res[[1]]), regexp = NA)
   expect_warning(print(resLearn), regexp = NA)
   expect_warning(print(resLearn$res[[1]]), regexp = NA)
 })
 
-Sys.unsetenv("MC_DETERMINISTIC")
\ No newline at end of file
+Sys.unsetenv("MC_DETERMINISTIC")
